#!/bin/bash

############################
# sentinelle.sh
# instructions spécifiques au module sentinelle
############################

# ========================================
# CHANGE
#
# 14/09/07 : CLEON 
#    AJOUT url_data=https://$adresse_ip_eth0/sentinelle/classes/CData.php dans le profile par défaut
#    AJOUT sed -i $EXPR /var/www/sentinelle/classes/inc.php après la copie du repertoire web 
#		afin de modifier le mot de passe sentinelle d'accès à la base    

# Appel Bibliothèque
. ParseDico

InstallDir=/usr/share/sentinelle
PasswordFile=/usr/share/sentinelle/password
WWWHOME=/var/www/sentinelle
SentinelleDir=/usr/share/sentinelle-server

# installation des runtimes java
dpkg -l sun-java6-jre 2>/dev/null | grep -q ^ii
if [ $? -ne 0 ]
then
	echo "Mise à jour de la base de paquets..."
	Query-Auto > /dev/null
	echo "Installation des librairies java..."
	apt-get install -y sun-java6-jre
	if [ $? -ne 0 ]
	then
		echo "Les runtime java 6 sont nécessaires au fonctionnement de sentinelle."
		echo -e "Abandon de la procédure d'instance\n"
		exit 1
	fi
fi

REP="n"
if [ -e $PasswordFile ] ; then
	echo -n "Les mots passes sont déjà définis, voulez-vous les changer (o/n) ? :"
	read REP
else
	REP="o"
fi

if [ $REP == "o" -o  $REP == "oui" ] ; then
	stty -echo
	# saisie du mot de passe de l'administrateur mysql
	read -p "Mot de passe root mysql        ? " MYSQL_ROOT_PWD
	echo
	read -p "Confirmation du mot de passe   ? " MYSQL_ROOT_PWD2
	echo
	while [ $MYSQL_ROOT_PWD != $MYSQL_ROOT_PWD2 ]
	do
		read -p "Mot de passe root mysql        ? " MYSQL_ROOT_PWD
		echo
		read -p "Confirmation du mot de passe   ? " MYSQL_ROOT_PWD2
		echo
	done
	# saisie du mot de passe de l'administrateur mysql
	read -p "Mot de passe sentinelle (mysql) ? " MYSQL_SENTINELLE_PWD
	echo
	read -p "Confirmation du mot de passe   ? " MYSQL_SENTINELLE_PWD2
	echo
	while [ $MYSQL_SENTINELLE_PWD != $MYSQL_SENTINELLE_PWD2 ]
	do
		read -p "Mot de passe sentinelle (mysql)  ? " MYSQL_SENTINELLE_PWD
		echo
		read -p "Confirmation du mot de passe     ? " MYSQL_SENTINELLE_PWD2
		echo
	done
	# Accès à zephir
	stty echo
	echo "Acces a zephir"
	echo -n "  login : " ; read ZEPHIR_LOGIN
	stty -echo
	echo -n "  mot de passe : " ; read ZEPHIR_PASSWORD
	echo ""
	stty echo


else
	eval `cat  $PasswordFile`
fi

## Creation du nouveau mot de passe root
/usr/bin/python /usr/share/eole/mysql_pwd.py $MYSQL_ROOT_PWD

## Sentinelle
if [ ! -f /var/lib/mysql/sentinelle/db.opt ]
then
	if [ -f $InstallDir/sql_structure.sql ]
	then
	   echo -n "Génération de la base Sentinelle            :"
	   mysql -u root --password=$MYSQL_ROOT_PWD < $InstallDir/sql_structure.sql # > /dev/null 2>&1
	   mysql  --user=root --password=$MYSQL_ROOT_PWD -e "SET PASSWORD FOR 'sentinelle'@'localhost' = PASSWORD('$MYSQL_SENTINELLE_PWD');"
	   echo " OK"
	 fi
fi

pushd $InstallDir > /dev/null

INC_ZEPHIR="zephir/scripts/inc_connect.py"
echo "sUserName='$ZEPHIR_LOGIN'"    >   $INC_ZEPHIR
echo "sPasswd='$ZEPHIR_PASSWORD'"  >>   $INC_ZEPHIR
echo "sIp='$adresse_zephir:7080'" >>   $INC_ZEPHIR
echo "sUrlZephir='https://'+ sUserName +':'+ sPasswd + '@' + sIp" >>   $INC_ZEPHIR

R=`python zephir/scripts/testconnect.py`
R="1"
if [ "$R" == "0" ] ; then
	echo "Impossible de se connecter à Zephir : $adresse_zephir:7080 "
	exit
fi

echo ""
echo -n "Récupération des établissements             :"
python zephir/scripts/RecupEtabsClientFromZephir.py 
if [ $? -eq 1 ] ; then
	echo "Erreur lors de la récupération, vérifier vos identifiants zephir "
	exit
fi

L=`cat sentinelle/conf/etabs.txt | wc -l` ; L=`expr $L + 0`
echo " $L établissements récupérés"
#rm -rf $INC_ZEPHIR

#======================================================================================

if [ -d $SentinelleDir ] ; then
	rm -rf $SentinelleDir
fi


#======================================================================================

echo -n "Génération des certificats                  : "
# certificat pour apache
if [ ! -e /etc/ssl/apache2/server.crt ]
then
        #echo -e "\n## Génération du certificaApache ##"
        /usr/share/eole/gen_certifSentinelle.sh
fi


EXPR="s/%%ACADEMIE%%/$nom_academie/g"
sed $EXPR conf/certif-apache.conf > certif-apache.conf
if [ ! -d /etc/ssl/sentinelle ] ; then
	mkdir /etc/ssl/sentinelle
else
	rm -rf /etc/ssl/sentinelle/*
fi
openssl req -x509 -new -newkey rsa:1024 -days 1825 -out /etc/ssl/sentinelle/server.crt -config certif-apache.conf >/dev/null 2>&1
openssl rsa -in /etc/ssl/sentinelle/server.key -passin pass:secret -out /etc/ssl/sentinelle/server.key >/dev/null 2>&1

rm -rf certif-apache.conf

cp -f /etc/apache2/mods-available/ssl.* /etc/apache2/mods-enabled
/etc/init.d/apache2 restart >/dev/null 2>&1


#======================================================================================
KEYTOOL=/usr/lib/jvm/java-6-sun-1.6.0.00/bin/keytool
SRV_STOREPASS=`pwgen -1`
SRV_KEYPASS=$SRV_STOREPASS
CLT_STOREPASS=`pwgen -1`
CLT_KEYPASS=$CLT_STOREPASS

$KEYTOOL -genkey -alias sentinellesrv -keypass $SRV_KEYPASS -storepass $SRV_STOREPASS -dname "CN=Sentinelle Serveur@$nom_academie, OU=$nom_academie, O=GOUV, L=, S=, C=FR"   -keyalg RSA -keystore /etc/ssl/sentinelle/serveur.ks  >/dev/null
$KEYTOOL -export -alias sentinellesrv -keystore /etc/ssl/sentinelle/serveur.ks -file /etc/ssl/sentinelle/serveur.cert -storepass $SRV_STOREPASS  >/dev/null

$KEYTOOL -genkey -alias sentinelleclient -keypass $CLT_KEYPASS -storepass $CLT_STOREPASS -dname "CN=Sentinelle Client@$nom_academie, OU=$nom_academie, O=GOUV, L=, S=, C=FR"     -keyalg RSA -keystore /etc/ssl/sentinelle/client.ks >/dev/null
$KEYTOOL -import -alias sentinellesrv -keystore /etc/ssl/sentinelle/client.ts -file /etc/ssl/sentinelle/serveur.cert -keypass $SRV_KEYPASS -storepass $CLT_STOREPASS -noprompt >/dev/null


echo " OK"
# ===================================================================================

# Si le répertoire local n'existe pas on le crée
if [ ! -d /etc/sentinelle ] ; then
	mkdir /etc/sentinelle
	mkdir /etc/sentinelle/client
	mkdir /etc/sentinelle/client/_client
	LOCALDEPS="/etc/sentinelle/client/local.deps"
	echo "_client/etabs.txt" >  $LOCALDEPS
	echo "_client/carte.png" >> $LOCALDEPS
fi


if [ ! -e /etc/sentinelle/client/_client/etabs.txt ] ; then
	echo "Le fichier de coordonnées des établissements n'éxiste pas"
	echo -n " Voulez-vous le créer maintenant o/n ?"; read R
	if [ "$R" = "o" -o "$R" = "O" ] ; then
		python zephir/scripts/RecupGPSEtabsFromZephir.py	

	fi
fi

if [ ! -e /etc/sentinelle/client/_client/carte.png ] ; then
	echo "Aucun fond de carte trouvé :"
	echo "-> Veuillez copier votre carte dans"
	echo "   /etc/sentinelle/client/_client/carte.png"
	echo ""
fi


cp /dev/null $PasswordFile
echo "MYSQL_ROOT_PWD=\"$MYSQL_ROOT_PWD\""               >> $PasswordFile
echo "MYSQL_SENTINELLE_LOGIN=\"sentinelle\""            >> $PasswordFile
echo "MYSQL_SENTINELLE_PWD=\"$MYSQL_SENTINELLE_PWD\""   >> $PasswordFile
echo "ZEPHIR_LOGIN=\"$ZEPHIR_LOGIN\""                   >> $PasswordFile
echo "ZEPHIR_PASSWORD=\"$ZEPHIR_PASSWORD\""             >> $PasswordFile
echo "SRV_KEYPASS=$SRV_KEYPASS"				>> $PasswordFile
echo "SRV_STOREPASS=$SRV_STOREPASS"			>> $PasswordFile
echo "CLT_KEYPASS=$CLT_KEYPASS"                         >> $PasswordFile
echo "CLT_STOREPASS=$CLT_STOREPASS"                     >> $PasswordFile

reconf-sentinelle.sh

popd > /dev/null
